Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGuillermo S. Romero <gsr.b3d@infernal-iceberg.com>2010-08-30 23:51:12 +0400
committerGuillermo S. Romero <gsr.b3d@infernal-iceberg.com>2010-08-30 23:51:12 +0400
commiteb7c02c2a0f8c2172c2b6b402ab94debaa7e3007 (patch)
tree79855a3444c9bc17f26c9369cc8371bd775541f5 /release/scripts/io
parentd59304e8e45356e1617f55e58e5142aafb1bb30c (diff)
Fix spelling.
Diffstat (limited to 'release/scripts/io')
-rw-r--r--release/scripts/io/import_scene_obj.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/release/scripts/io/import_scene_obj.py b/release/scripts/io/import_scene_obj.py
index 3b44803feea..3a92ec8c5ae 100644
--- a/release/scripts/io/import_scene_obj.py
+++ b/release/scripts/io/import_scene_obj.py
@@ -860,7 +860,7 @@ def strip_slash(line_split):
def get_float_func(filepath):
'''
find the float function for this obj file
- - weather to replace commas or not
+ - whether to replace commas or not
'''
file= open(filepath, 'rU')
for line in file: #.xreadlines():
@@ -931,7 +931,7 @@ def load_obj(filepath,
# when there are faces that end with \
# it means they are multiline-
# since we use xreadline we cant skip to the next line
# so we need to know weather
context_multi_line= ''
print("\tparsing obj file...")
@@ -931,7 +931,7 @@ def load_obj(filepath,
# it means they are multiline-
# since we use xreadline we cant skip to the next line
- # so we need to know weather
+ # so we need to know whether
context_multi_line= ''
print("\tparsing obj file...")